import Imap from 'imap';
import { ParsedMail } from 'mailparser';
export declare type ImapConfig = Omit<Imap.Config, 'user' | 'password'>;
export interface ImapEmailsProps {
    /**
     * If you're using Gmail, this is your email address
     */
    username: string;
    /**
     * If you're using Gmail you need to set up "App Password".
     * You will not be able to use your regular Gmail password.
     * Check out this for example:
     * https://support.google.com/accounts/answer/185833?hl=en
     */
    password: string;
    /**
     * Default configuration is connecting to gmail
     * @example
     * const GMAIL_IMAP_CONFIG: ImapConfig = {
     *   host: 'imap.gmail.com',
     *   port: 993,
     *   tls: true,
     *   tlsOptions: {
     *     servername: 'imap.gmail.com',
     *   },
     * };
     */
    imapConfig?: Omit<Imap.Config, 'user' | 'password'>;
}
export interface GetEmailsStreamsProps {
    since: Date;
}
export interface GetEmailsProps extends GetEmailsStreamsProps {
}
/**
 * ImapEmails is wrapping "imap" and "mailparser" library and exposes
 * simple interface to fetch your latest emails from Gmail or any
 * other inbox supporting IMAP
 * @example
 * const imapEmails = await ImapEmails({
 *   username: 'example@gmail.com',
 *   password: 'example-gmail-app-password'
 * });
 *
 * await imapEmails.connect();
 *
 * const emails = await imapEmails.getEmails({ since: new Date('2022-09-01T00:00:00.000Z') });
 *
 * await imapEmails.disconnect();
 */
export declare class ImapEmails {
    private imap;
    constructor({ username, password, imapConfig, }: ImapEmailsProps);
    connect(): Promise<void>;
    disconnect(): Promise<void>;
    private _getEmailsStreams;
    getEmails({ since }: GetEmailsProps): Promise<ParsedMail[]>;
}
