"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ImapEmails = void 0;
const tslib_1 = require("tslib");
const imap_1 = tslib_1.__importDefault(require("imap"));
const mailparser_1 = require("mailparser");
const GMAIL_IMAP_CONFIG = {
    host: 'imap.gmail.com',
    port: 993,
    tls: true,
    tlsOptions: {
        servername: 'imap.gmail.com',
    },
};
/**
 * ImapEmails is wrapping "imap" and "mailparser" library and exposes
 * simple interface to fetch your latest emails from Gmail or any
 * other inbox supporting IMAP
 * @example
 * const imapEmails = await ImapEmails({
 *   username: 'example@gmail.com',
 *   password: 'example-gmail-app-password'
 * });
 *
 * await imapEmails.connect();
 *
 * const emails = await imapEmails.getEmails({ since: new Date('2022-09-01T00:00:00.000Z') });
 *
 * await imapEmails.disconnect();
 */
class ImapEmails {
    constructor({ username, password, imapConfig = GMAIL_IMAP_CONFIG, }) {
        this.imap = new imap_1.default(Object.assign({ user: username, password }, imapConfig));
    }
    connect() {
        return new Promise((resolve, reject) => {
            this.imap.once('ready', () => {
                resolve();
            });
            this.imap.once('error', (err) => {
                reject(err);
            });
            this.imap.connect();
        });
    }
    disconnect() {
        return new Promise((resolve) => {
            this.imap.once('end', () => {
                resolve();
            });
            this.imap.end();
        });
    }
    _getEmailsStreams({ since, }) {
        return new Promise((resolve, reject) => {
            const emailsStreams = [];
            this.imap.openBox('INBOX', true, (err) => {
                if (err)
                    reject(err);
                this.imap.search(['ALL', ['SINCE', since]], (err, uids) => {
                    if (err)
                        reject(err);
                    if (uids.length === 0)
                        return resolve([]);
                    const f = this.imap.fetch(uids, { bodies: '' });
                    f.on('message', (msg) => {
                        msg.on('body', (stream) => tslib_1.__awaiter(this, void 0, void 0, function* () {
                            emailsStreams.push(stream);
                        }));
                    });
                    f.once('error', (err) => {
                        reject(err);
                    });
                    f.once('end', () => {
                        resolve(emailsStreams);
                    });
                });
            });
        });
    }
    getEmails({ since }) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const emailsStreams = yield this._getEmailsStreams({ since });
            return yield Promise.all(emailsStreams.map((emailStream) => (0, mailparser_1.simpleParser)(emailStream)));
        });
    }
}
exports.ImapEmails = ImapEmails;
//# sourceMappingURL=imap-emails.js.map